package mapdemo;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * A demonstration of Java maps and enumerated types.
 *
 * <p>
 * File: <code>MapDemoMain.java</code>
 *
 * @author J. Stanley Warford
 * @see <a href="http://computersystemsbook.com"><i>Computer
 * Systems</i></a> textbook home page, <a
 * href="https://www.cslab.pepperdine.edu/warford/cosc330/">course</a> home page.
 */

public class MapDemoMain implements ActionListener {

   final JFrame mainWindowFrame;
   final JPanel inputPanel;
   final JLabel label;
   final JTextField textField;
   final JPanel buttonPanel;
   final JButton button;

   public MapDemoMain() {
      // Set up the main window.
      mainWindowFrame = new JFrame("Java Map Demonstration");
      mainWindowFrame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      mainWindowFrame.setSize(new Dimension(240, 120));

      // Lay out the label and text field input panel from top to bottom.
      inputPanel = new JPanel();
      inputPanel.setLayout(new BoxLayout(inputPanel, BoxLayout.PAGE_AXIS));
      label = new JLabel("Enter a planet:");
      inputPanel.add(label);
      textField = new JTextField(20);
      inputPanel.add(textField);
      inputPanel.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));

      // Lay out the button from left to right.
      buttonPanel = new JPanel();
      buttonPanel.setLayout(new BoxLayout(buttonPanel, BoxLayout.LINE_AXIS));
      buttonPanel.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
      buttonPanel.add(Box.createHorizontalGlue());
      button = new JButton("Enter");
      buttonPanel.add(button);
      buttonPanel.add(Box.createRigidArea(new Dimension(10, 0)));

      // Combine the input panel and the button panel in the main window.
      mainWindowFrame.add(inputPanel, BorderLayout.CENTER);
      mainWindowFrame.add(buttonPanel, BorderLayout.PAGE_END);

      textField.addActionListener(this);
      button.addActionListener(this);

      mainWindowFrame.pack();
      mainWindowFrame.setVisible(true);
   }

   private static void createAndShowGUI() {
      JFrame.setDefaultLookAndFeelDecorated(true);
      new MapDemoMain();
   }

   public static void main(String[] args) {
      javax.swing.SwingUtilities.invokeLater(MapDemoMain::createAndShowGUI);
   }

   @Override
   public void actionPerformed(ActionEvent event) {
      String line = textField.getText();
      if (Maps.planetTable.containsKey(line.toLowerCase())) {
         Planet planet = Maps.planetTable.get(line.toLowerCase());
         String planetString = Maps.planetStringTable.get(planet);
         switch (planet) {
            case P_MERCURY:
            case P_VENUS:
               System.out.printf("%s is close to the sun.\n", planetString);
               break;
            case P_EARTH:
               System.out.printf("The %s is indeed a planet.\n", planetString);
               break;
            case P_MARS:
               System.out.printf("Planet %s is red.\n", planetString);
               break;
            case P_JUPITER:
            case P_SATURN:
               System.out.printf("%s is a big planet.\n", planetString);
               break;
            case P_URANUS:
            case P_NEPTUNE:
            case P_PLUTO:
               System.out.printf("%s is far from the sun.\n", planetString);
         }
         System.out.printf("Enumerated output: %s\n", planet);
         System.out.printf("Ordinal output: %d\n", planet.ordinal());
      } else {
         System.out.println(line + " is not a planet.");
      }
   }
}
